@@ -128,16 +128,20 @@ mod tests {
         };
 
         let result = match res {
-            Response::Ok { result } => {
-                assert_eq!(result.address_components.len(), 7);
-                result
-            }
+            Response::Ok { result } => result,
             _ => {
                 assert!(false);
                 return;
             }
         };
 
+        let geometry = result.geometry.as_ref().unwrap();
+        assert_eq!(geometry.location.lat, 3.0270637);
+        assert_eq!(geometry.location.lng, 101.4379739);
+        assert_eq!(geometry.viewport.northeast.lat, 3.028371480291502);
+        assert_eq!(geometry.viewport.northeast.lng, 101.4393057302915);
+        assert_eq!(geometry.viewport.southwest.lat, 3.025673519708498);
+        assert_eq!(geometry.viewport.southwest.lng, 101.4366077697085);
         assert_eq!(result.street_number().unwrap(), "7");
         assert_eq!(result.route().unwrap(), "Leboh Palas");
         assert_eq!(result.sublocality().unwrap(), "Taman Selatan");
